package com.sooka.system.service.impl;

import java.util.List;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.sooka.system.mapper.TGuijiHealthcommissionTjxxMapper;
import com.sooka.system.domain.TGuijiHealthcommissionTjxx;
import com.sooka.system.service.ITGuijiHealthcommissionTjxxService;

/**
 * 体检信息表Service业务层处理
 *
 * @author lei
 * @date 2021-11-09
 */
@Service
public class TGuijiHealthcommissionTjxxServiceImpl extends Guiji_Base_Service implements ITGuijiHealthcommissionTjxxService
{
    @Autowired
    private TGuijiHealthcommissionTjxxMapper tGuijiHealthcommissionTjxxMapper;

    /**
     * 查询体检信息表
     *
     * @param id 体检信息表ID
     * @return 体检信息表
     */
    @Override
    public TGuijiHealthcommissionTjxx selectTGuijiHealthcommissionTjxxById(String id)
    {
        return tGuijiHealthcommissionTjxxMapper.selectTGuijiHealthcommissionTjxxById(id);
    }

    /**
     * 查询体检信息表列表
     *
     * @param tGuijiHealthcommissionTjxx 体检信息表
     * @return 体检信息表
     */
    @Override
    public List<TGuijiHealthcommissionTjxx> selectTGuijiHealthcommissionTjxxList(TGuijiHealthcommissionTjxx tGuijiHealthcommissionTjxx)
    {
        List ls = tGuijiHealthcommissionTjxxMapper.selectTGuijiHealthcommissionTjxxList(tGuijiHealthcommissionTjxx);

        tGuijiHealthcommissionTjxx.setInterfaceinfoId("0b315bc2-2eeb-46e7-b952-3df0fa70442c");
        tGuijiHealthcommissionTjxx.setInterfaceinfoName("共享-体检-体检信息表");
        tGuijiHealthcommissionTjxx.setInterfacetype("platform_interfacetype_1");
        add_log(tGuijiHealthcommissionTjxx);
        return ls;
    }

    /**
     * 新增体检信息表
     *
     * @param tGuijiHealthcommissionTjxx 体检信息表
     * @return 结果
     */
    @Override
    public int insertTGuijiHealthcommissionTjxx(TGuijiHealthcommissionTjxx tGuijiHealthcommissionTjxx)
    {
        tGuijiHealthcommissionTjxx.setCreateTime(DateUtils.getNowDate());
        return tGuijiHealthcommissionTjxxMapper.insertTGuijiHealthcommissionTjxx(tGuijiHealthcommissionTjxx);
    }

    /**
     * 修改体检信息表
     *
     * @param tGuijiHealthcommissionTjxx 体检信息表
     * @return 结果
     */
    @Override
    public int updateTGuijiHealthcommissionTjxx(TGuijiHealthcommissionTjxx tGuijiHealthcommissionTjxx)
    {
        return tGuijiHealthcommissionTjxxMapper.updateTGuijiHealthcommissionTjxx(tGuijiHealthcommissionTjxx);
    }

    /**
     * 删除体检信息表对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTGuijiHealthcommissionTjxxByIds(String ids)
    {
        return tGuijiHealthcommissionTjxxMapper.deleteTGuijiHealthcommissionTjxxByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除体检信息表信息
     *
     * @param id 体检信息表ID
     * @return 结果
     */
    @Override
    public int deleteTGuijiHealthcommissionTjxxById(String id)
    {
        return tGuijiHealthcommissionTjxxMapper.deleteTGuijiHealthcommissionTjxxById(id);
    }
}
